spoon

Package spoon |
[show private | hide private]
[frames | no frames]

## Package spoon

Submodules
`messaging` `decorators` `messaging` `NullLogger` `ber`: The low level BER based encoding used by spoon to serialize objects. `common` `stream` `tag` `objTypes` `routing` `MeshRouter`: Mesh Routing, this is the protocol by which an ad-hoc network of nodes can be created and how messages may be passed between them. `spoon` `spoonstream` `transports` `SpoonTransport` `transports`

Variable Summary
`str` | `__author__` = `'Matt Sullivan <matts@zarrf.com>'`
`str` | `__date__` = `'22 Nov 2006'`
`str` | `__license__` = `'MIT/X Consortium'`
`str` | `__version__` = `'0.1.1'`
`tuple` | `__version_info__` = `(0, 1, 1)`

Variable Details

    ### __author__ Type: `str` Value:
        'Matt Sullivan <matts@zarrf.com>'

    ### __date__ Type: `str` Value:
        '22 Nov 2006'

    ### __license__ Type: `str` Value:
        'MIT/X Consortium'

    ### __version__ Type: `str` Value:
        '0.1.1'

    ### __version_info__ Type: `tuple` Value:
        (0, 1, 1)

Generated by Epydoc 2.1 on Sun Nov 26 15:33:58 2006 | http://epydoc.sf.net